@@ -1,10 +1,5 @@
-"""Default environment
-Edit service environment to override
-"""
-################################################################################
-# Base Environment
-################################################################################
 import logging
+import sys
 from pathlib import Path
 from typing import Optional
 
